@@ -66,7 +66,7 @@ class BrokerStreams():
             raise traceback.format_exc()
 
 
-consumerNames = [
+topics_name = [
     'c.internal.extractor.insta',
     'c.internal.extractor.facebook',
     'c.internal.extractor.linkedin',
@@ -74,15 +74,13 @@ consumerNames = [
     'c.internal.transform.insta',
     'c.internal.transform.linkedin',
     'c.internal.graph.create',
-]
-
-providerNames = [
     'p.internal.transform.insta',
     'p.internal.transform.facebook',
     'p.internal.transform.linkedin',
     'p.internal.graph.create'
 ]
 
+
 class StatusSearch(Enum):
     PROGRESS = 'PROGRESS'
     FAILED = 'FAILED'
